@@ -10,7 +10,6 @@
 
 #include "mainwindow.h"
 #include "ark_debug.h"
-#include "archive_kerfuffle.h"
 #include "createdialog.h"
 #include "settingsdialog.h"
 #include "settingspage.h"
@@ -27,13 +26,14 @@
 #include <KSharedConfig>
 #include <KConfigDialog>
 #include <KXMLGUIFactory>
-#include <KPluginLoader>
 #include <KConfigSkeleton>
+#include <KToolBar>
 
 #include <QApplication>
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 #include <QFileDialog>
+#include <QMenuBar>
 #include <QMimeData>
 #include <QPointer>
 #include <QStatusBar>
@@ -118,9 +118,7 @@ void MainWindow::dragMoveEvent(QDragMoveEvent * event)
 
 bool MainWindow::loadPart()
 {
-    KPluginFactory *factory = KPluginLoader(QStringLiteral("kf5/parts/arkpart")).factory();
-
-    m_part = factory ? static_cast<KParts::ReadWritePart*>(factory->create<KParts::ReadWritePart>(this)) : nullptr;
+    m_part = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/parts/arkpart"))).plugin;
 
     if (!m_part) {
         KMessageBox::error(this, i18n("Unable to find Ark's KPart component, please check your installation."));
@@ -131,10 +129,23 @@ bool MainWindow::loadPart()
     m_part->setObjectName(QStringLiteral("ArkPart"));
     m_windowContents->addWidget(m_part->widget());
 
+    // needs to be above createGUI()
+    KHamburgerMenu * const hamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, m_part->actionCollection());
+    connect(hamburgerMenu, &KHamburgerMenu::aboutToShowMenu,
+            this, &MainWindow::updateHamburgerMenu);
+    hamburgerMenu->setMenuBar(menuBar());
+
+    QAction * const showMenuBarAction = actionCollection()->action(
+                                    QLatin1String(KStandardAction::name(KStandardAction::ShowMenubar)));
+    hamburgerMenu->setShowMenuBarAction(showMenuBarAction);
+
     setXMLFile(QStringLiteral("arkui.rc"));
     setupGUI(ToolBar | Keys | Save);
     createGUI(m_part);
 
+    // FIXME: workaround for BUG 171080
+    showMenuBarAction->setChecked(!menuBar()->isHidden());
+
     statusBar()->hide();
 
     connect(m_part, SIGNAL(ready()), this, SLOT(updateActions()));
@@ -178,6 +189,51 @@ void MainWindow::setupActions()
     // Connect the welcome screen to actions created above
     connect(m_welcomeScreen, &WelcomeScreen::newClicked, m_newAction, &QAction::trigger);
     connect(m_welcomeScreen, &WelcomeScreen::openClicked, m_openAction, &QAction::trigger);
+
+    // add Menubar toggle to 'Settings' menu
+    KToggleAction* showMenuBar = KStandardAction::showMenubar(nullptr, nullptr, actionCollection());
+    showMenuBar->setWhatsThis(xi18nc("@info:whatsthis",
+            "This switches between having a <emphasis>Menubar</emphasis> "
+            "and having a <interface>Hamburger Menu</interface> button. Both "
+            "contain mostly the same commands and configuration options."));
+    connect(showMenuBar, &KToggleAction::triggered,                   // Fixes #286822
+            this, [this]{ menuBar()->setVisible(!menuBar()->isVisible()); }, Qt::QueuedConnection);
+}
+
+void MainWindow::updateHamburgerMenu()
+{
+    const KActionCollection* ac = m_part->actionCollection();
+    auto hamburgerMenu = static_cast<KHamburgerMenu *>(
+                    ac->action(QLatin1String(KStandardAction::name(KStandardAction::HamburgerMenu))));
+    auto menu = hamburgerMenu->menu();
+    if (!menu) {
+        menu = new QMenu(this);
+        hamburgerMenu->setMenu(menu);
+    } else {
+        menu->clear();
+    }
+
+    if (!toolBar()->isVisible()) {
+        // If neither the menu bar nor the toolbar are visible, these actions should be available.
+        menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::ShowMenubar))));
+        menu->addAction(toolBarMenuAction());
+        menu->addSeparator();
+    }
+
+    menu->addAction(m_newAction);
+    menu->addAction(m_openAction);
+    menu->addMenu(m_recentFilesMenu);
+    menu->addSeparator();
+
+    menu->addAction(ac->action(QStringLiteral("extract")));
+    menu->addAction(ac->action(QStringLiteral("add")));
+    menu->addAction(ac->action(QStringLiteral("edit_find")));
+    menu->addSeparator();
+
+    menu->addMenu(static_cast<QMenu *>(factory()->container(QStringLiteral("ark_file"), m_part)));
+    menu->addSeparator();
+
+    menu->addMenu(static_cast<QMenu *>(factory()->container(QStringLiteral("settings"), this)));
 }
 
 void MainWindow::updateActions()
@@ -248,7 +304,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 // Set a sane default window size
 QSize MainWindow::sizeHint() const
 {
-    return QSize(700, 500);
+    return QSize(950, 600);
 }
 
 void MainWindow::quit()
