@@ -15,6 +15,13 @@
 
 using namespace Kerfuffle;
 
+void initLocale()
+{
+    qputenv("LANG", "en_US");
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+
 class AddToArchiveTest : public QObject
 {
     Q_OBJECT
@@ -75,6 +82,10 @@ void AddToArchiveTest::testCompressHere_data()
     QTest::newRow("compress here (as TAR) - files with same prefix")
         << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/textfile1.txt"), QFINDTESTDATA("data/textfile2.txt")}
         << QStringLiteral("textfile.tar.gz") << 2ULL;
+    
+    QTest::newRow("compress here (as TAR) - files with same base name")
+        << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt"), QFINDTESTDATA("data/testfile.md")}
+        << QStringLiteral("testfile.tar.gz") << 2ULL;
 
     QTest::newRow("compress here (as TAR) - files with same prefix too short")
         << QStringLiteral("tar.gz") << Archive::Unencrypted << QStringList{QFINDTESTDATA("data/testfile.txt"), QFINDTESTDATA("data/textfile2.txt")}
@@ -87,6 +98,13 @@ void AddToArchiveTest::testCompressHere_data()
         << QStringLiteral("test-3.4.0.tar.gz")
         << 2ULL;
 
+    QTest::newRow("compress here (as TAR) - files with mimetypes but no extension (no infinite loop)")
+        << QStringLiteral("tar.gz")
+        << Archive::Unencrypted
+        << QStringList {QFINDTESTDATA("data/Makefile"), QFINDTESTDATA("data/README")}
+        << QStringLiteral("Archive.tar.gz")
+        << 2ULL;
+
     if (!PluginManager().preferredWritePluginsFor(QMimeDatabase().mimeTypeForName(QStringLiteral("application/zip"))).isEmpty()) {
         QTest::newRow("compress here (as ZIP) - dir with files")
             << QStringLiteral("zip")
