@@ -929,6 +929,15 @@ bool CliInterface::handleLine(const QString& line)
         }
     }
 
+    if (m_operationMode == Move && isNewMovedFileNamesMsg(line)) {
+        QString fNames;
+        for (auto entry : qAsConst(m_newMovedFiles)) {
+            fNames += QStringLiteral("%1\n").arg(entry->fullPath(NoTrailingSlash));
+        }
+        writeToProcess(fNames.toLocal8Bit());
+        return true;
+    }
+
     return true;
 }
 
@@ -1126,4 +1135,10 @@ bool CliInterface::isFileExistsFileName(const QString &line)
     return false;
 }
 
+bool CliInterface::isNewMovedFileNamesMsg(const QString &line)
+{
+    Q_UNUSED(line);
+    return false;
+}
+
 }
