@@ -9,16 +9,21 @@
 #include "arkviewer.h"
 #include "ark_debug.h"
 
-#include <KIO/JobUiDelegate>
-#include <KIO/ApplicationLauncherJob>
-#include <KLocalizedString>
-#include <KMimeTypeTrader>
-#include <KMessageBox>
-#include <KParts/OpenUrlArguments>
-#include <KXMLGUIFactory>
-#include <KActionCollection>
 #include <KAboutPluginDialog>
+#include <KActionCollection>
+#include <KApplicationTrader>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KMimeTypeTrader>
+#include <KParts/OpenUrlArguments>
+#include <KParts/PartLoader>
 #include <KPluginMetaData>
+#include <KXMLGUIFactory>
+
+#include <kparts_version.h>
 
 #include <QFile>
 #include <QMimeDatabase>
@@ -76,13 +81,13 @@ void ArkViewer::openExternalViewer(const KService::Ptr viewer, const QString& fi
     const QList<QUrl> fileUrlList = {QUrl::fromLocalFile(fileName)};
     KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(viewer);
     job->setUrls(fileUrlList);
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
     // The temporary file will be removed when the viewer application exits.
     job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
     job->start();
 }
 
-void ArkViewer::openInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType)
+void ArkViewer::openInternalViewer(const KPluginMetaData& viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType)
 {
     qCDebug(ARK) << "Opening internal viewer";
 
@@ -95,7 +100,7 @@ void ArkViewer::openInternalViewer(const KService::Ptr viewer, const QString& fi
         return;
     }
     else {
-        KMessageBox::sorry(nullptr, i18n("The internal viewer cannot preview this file."));
+        KMessageBox::error(nullptr, i18n("The internal viewer cannot preview this file."));
         delete internalViewer;
 
         qCDebug(ARK) << "Removing temporary file:" << fileName;
@@ -134,16 +139,15 @@ bool ArkViewer::askViewAsPlainText(const QMimeType& mimeType)
     return response != KMessageBox::Cancel;
 }
 
-void ArkViewer::view(const QString& fileName, const QString& entryPath)
+void ArkViewer::view(const QString& fileName, const QString& entryPath, const QMimeType& mimeType)
 {
     QMimeDatabase db;
-    QMimeType mimeType = db.mimeTypeForFile(fileName);
     qCDebug(ARK) << "viewing" << fileName << "from" << entryPath << "with mime type:" << mimeType.name();
 
-    const KService::Ptr internalViewer = ArkViewer::getInternalViewer(mimeType.name());
+    const std::optional<KPluginMetaData> internalViewer = ArkViewer::getInternalViewer(mimeType.name());
 
     if (internalViewer) {
-        openInternalViewer(internalViewer, fileName, entryPath, mimeType);
+        openInternalViewer(*internalViewer, fileName, entryPath, mimeType);
         return;
     }
 
@@ -157,22 +161,60 @@ void ArkViewer::view(const QString& fileName, const QString& entryPath)
     // No internal or external viewer available for the file.  Ask the user if it
     // should be previewed as text/plain.
     if (askViewAsPlainText(mimeType)) {
-        const KService::Ptr textViewer = ArkViewer::getInternalViewer(QStringLiteral("text/plain"));
-        openInternalViewer(textViewer, fileName, entryPath, db.mimeTypeForName(QStringLiteral("text/plain")));
-    } else {
-        qCDebug(ARK) << "Removing temporary file:" << fileName;
-        QFile::remove(fileName);
+        const std::optional<KPluginMetaData> textViewer = ArkViewer::getInternalViewer(QStringLiteral("text/plain"));
+
+        if (textViewer) {
+            openInternalViewer(*textViewer, fileName, entryPath, db.mimeTypeForName(QStringLiteral("text/plain")));
+            return;
+        }
     }
+    qCDebug(ARK) << "Removing temporary file:" << fileName;
+    QFile::remove(fileName);
 }
 
-bool ArkViewer::viewInInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString& entryPath, const QMimeType &mimeType)
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 100, 0)
+// Copied from kparts/partloader.h
+namespace KParts::PartLoader {
+template<typename T>
+static KPluginFactory::Result<T>
+instantiatePart(const KPluginMetaData &data, QWidget *parentWidget = nullptr, QObject *parent = nullptr, const QVariantList &args = {})
+{
+    KPluginFactory::Result<T> result;
+    KPluginFactory::Result<KPluginFactory> factoryResult = KPluginFactory::loadFactory(data);
+    if (!factoryResult.plugin) {
+        result.errorString = factoryResult.errorString;
+        result.errorReason = factoryResult.errorReason;
+        return result;
+    }
+    T *instance = factoryResult.plugin->create<T>(parentWidget, parent, args);
+    if (!instance) {
+        const QString fileName = data.fileName();
+        result.errorString = QObject::tr("KPluginFactory could not load the plugin: %1").arg(fileName);
+        result.errorText = QStringLiteral("KPluginFactory could not load the plugin: %1").arg(fileName);
+        result.errorReason = KPluginFactory::INVALID_KPLUGINFACTORY_INSTANTIATION;
+    } else {
+        result.plugin = instance;
+    }
+    return result;
+}
+}
+#endif
+
+bool ArkViewer::viewInInternalViewer(const KPluginMetaData& viewer, const QString& fileName, const QString& entryPath, const QMimeType &mimeType)
 {
     // Set icon and comment for the mimetype.
     m_iconLabel->setPixmap(QIcon::fromTheme(mimeType.iconName()).pixmap(style()->pixelMetric(QStyle::PixelMetric::PM_SmallIconSize)));
     m_commentLabel->setText(mimeType.comment());
 
     // Create the ReadOnlyPart instance.
-    m_part = viewer->createInstance<KParts::ReadOnlyPart>(this, this);
+    const auto result = KParts::PartLoader::instantiatePart<KParts::ReadOnlyPart>(viewer, this, this);
+
+    if (!result) {
+        qCDebug(ARK) << "Failed to create internal viewer" << result.errorString;
+        return false;
+    }
+
+    m_part = result.plugin;
 
     if (!m_part.data()) {
         return false;
@@ -206,27 +248,21 @@ bool ArkViewer::viewInInternalViewer(const KService::Ptr viewer, const QString&
 
 KService::Ptr ArkViewer::getExternalViewer(const QString &mimeType)
 {
-    KService::List offers = KMimeTypeTrader::self()->query(mimeType, QStringLiteral("Application"));
-
-    if (!offers.isEmpty()) {
-        return offers.first();
-    } else {
-        return KService::Ptr();
-    }
+    return KApplicationTrader::preferredService(mimeType);
 }
 
-KService::Ptr ArkViewer::getInternalViewer(const QString& mimeType)
+std::optional<KPluginMetaData> ArkViewer::getInternalViewer(const QString& mimeType)
 {
     // No point in even trying to find anything for application/octet-stream
     if (mimeType == QLatin1String("application/octet-stream")) {
-        return KService::Ptr();
+        return {};
     }
 
     // Try to get a read-only kpart for the internal viewer
-    KService::List offers = KMimeTypeTrader::self()->query(mimeType, QStringLiteral("KParts/ReadOnlyPart"));
+    QVector<KPluginMetaData> offers = KParts::PartLoader::partsForMimeType(mimeType);
 
-    auto arkPartIt = std::find_if(offers.begin(), offers.end(), [](KService::Ptr service) {
-        return service->storageId() == QLatin1String("ark_part.desktop");
+    auto arkPartIt = std::find_if(offers.begin(), offers.end(), [](const KPluginMetaData& service) {
+        return service.pluginId() == QLatin1String("arkpart");
     });
 
     // Use the Ark part only when the mime type matches an archive type directly.
@@ -234,24 +270,35 @@ KService::Ptr ArkViewer::getInternalViewer(const QString& mimeType)
     // but browsing their internals is typically not what the user wants.
     if (arkPartIt != offers.end()) {
         // Not using hasMimeType() as we're explicitly not interested in inheritance.
-        if (!(*arkPartIt)->mimeTypes().contains(mimeType)) {
+        if (!arkPartIt->mimeTypes().contains(mimeType)) {
             offers.erase(arkPartIt);
         }
     }
 
     // Skip the KHTML part
-    auto khtmlPart = std::find_if(offers.begin(), offers.end(), [](KService::Ptr service) {
-        return service->desktopEntryName() == QLatin1String("khtml");
+    auto khtmlPart = std::find_if(offers.begin(), offers.end(), [](const KPluginMetaData &part) {
+        return part.pluginId() == QLatin1String("khtmlpart");
     });
 
     if (khtmlPart != offers.end()) {
         offers.erase(khtmlPart);
     }
 
+
+    // The oktetapart can open any file, but a hex viewer isn't really useful here
+    // Skip it so we prefer an external viewer instead
+    auto oktetaPart = std::find_if(offers.begin(), offers.end(), [](const KPluginMetaData &part) {
+        return part.pluginId() == QLatin1String("oktetapart");
+    });
+
+    if (oktetaPart != offers.end()) {
+        offers.erase(oktetaPart);
+    }
+
     if (!offers.isEmpty()) {
-        return offers.first();
+        return offers.at(0);
     } else {
-        return KService::Ptr();
+        return {};
     }
 }
 
