@@ -29,22 +29,24 @@
 #include "pluginsettingspage.h"
 #include "pluginmanager.h"
 
-#include <KPluginMetaData>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
-#include <KJobWidgets>
 #include <KIO/StatJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KParts/OpenUrlArguments>
 #include <KPluginFactory>
+#include <KPluginMetaData>
 #include <KStandardGuiItem>
 #include <KToggleAction>
-#include <KLocalizedString>
 #include <KXMLGUIFactory>
+#include <kwidgetsaddons_version.h>
 
 #include <QAction>
 #include <QCursor>
@@ -304,7 +306,7 @@ void Part::extractSelectedFilesTo(const QString& localPath)
             const QString udsLocalPath = statJob->statResult().stringValue(KIO::UDSEntry::UDS_LOCAL_PATH);
             if (udsLocalPath.isEmpty()) { // The URL could not be resolved to a local path
                 qCWarning(ARK) << "Ark cannot extract to non-local destination:" << localPath;
-                KMessageBox::sorry(widget(), xi18nc("@info", "Ark can extract archives to local destinations only."));
+                KMessageBox::error(widget(), xi18nc("@info", "Ark can extract archives to local destinations only."));
                 return;
             }
 
@@ -329,6 +331,9 @@ void Part::setupView()
 
     m_filterModel->setSourceModel(m_model);
     m_view->setModel(m_filterModel);
+
+    m_view->setItemDelegate(new NoHighlightSelectionDelegate(this));
+
     m_filterModel->setFilterKeyColumn(0);
     m_filterModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
@@ -367,14 +372,13 @@ void Part::setupActions()
     actionCollection()->addAction(QStringLiteral("ark_file_save_as"), m_saveAsAction);
 
     m_openFileAction = actionCollection()->addAction(QStringLiteral("openfile"));
-    m_openFileAction->setText(i18nc("open a file with external program", "&Open"));
-    m_openFileAction->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
-    m_openFileAction->setToolTip(i18nc("@info:tooltip", "Click to open the selected file with the associated application"));
+    m_openFileAction->setText(i18nc("open a file with external program", "&Open in External Application"));
+    m_openFileAction->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
     connect(m_openFileAction, &QAction::triggered, this, [this]() { slotOpenEntry(OpenFile); });
 
     m_openFileWithAction = actionCollection()->addAction(QStringLiteral("openfilewith"));
     m_openFileWithAction->setText(i18nc("open a file with external program", "Open &With..."));
-    m_openFileWithAction->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
+    m_openFileWithAction->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
     m_openFileWithAction->setToolTip(i18nc("@info:tooltip", "Click to open the selected file with an external program"));
     connect(m_openFileWithAction, &QAction::triggered, this, [this]() { slotOpenEntry(OpenFileWith); });
 
@@ -409,6 +413,7 @@ void Part::setupActions()
     m_renameFileAction = KStandardAction::renameFile(m_view, &ArchiveView::renameSelectedEntry, actionCollection());
 
     m_deleteFilesAction = KStandardAction::deleteFile(this, &Part::slotDeleteFiles, actionCollection());
+    m_deleteFilesAction->setText(i18nc("@action", "Remove from Archive"));
     m_deleteFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-remove")));
     actionCollection()->setDefaultShortcut(m_deleteFilesAction, Qt::Key_Delete);
 
@@ -856,15 +861,23 @@ bool Part::isLocalFileValid()
 bool Part::confirmAndDelete(const QString &targetFile)
 {
     QFileInfo targetInfo(targetFile);
-    const auto buttonCode = KMessageBox::warningYesNo(widget(),
-                                                      xi18nc("@info",
-                                                             "The archive <filename>%1</filename> already exists. Do you wish to overwrite it?",
-                                                             targetInfo.fileName()),
-                                                      i18nc("@title:window", "File Exists"),
-                                                      KStandardGuiItem::overwrite(),
-                                                      KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const auto buttonCode = KMessageBox::warningTwoActions(
+        widget(),
+#else
+    const auto buttonCode =
+        KMessageBox::warningYesNo(widget(),
+#endif
+        xi18nc("@info", "The archive <filename>%1</filename> already exists. Do you wish to overwrite it?", targetInfo.fileName()),
+        i18nc("@title:window", "File Exists"),
+        KStandardGuiItem::overwrite(),
+        KStandardGuiItem::cancel());
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (buttonCode != KMessageBox::PrimaryAction || !targetInfo.isWritable()) {
+#else
     if (buttonCode != KMessageBox::Yes || !targetInfo.isWritable()) {
+#endif
         return false;
     }
 
@@ -898,12 +911,13 @@ void Part::slotCompleted()
     if (m_model->rowCount() == 0) {
         qCWarning(ARK) << "No entry listed by the plugin";
         displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "The archive is empty or Ark could not open its content."));
-    } else if (m_model->rowCount() == 1) {
-        if (m_model->archive()->mimeType().inherits(QStringLiteral("application/x-cd-image")) &&
-            m_model->entryForIndex(m_model->index(0, 0))->fullPath() == QLatin1String("README.TXT")) {
-            qCWarning(ARK) << "Detected ISO image with UDF filesystem";
-            displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "Ark does not currently support ISO files with UDF filesystem."));
-        }
+    } else if (m_model->rowCount() == 1 &&
+               m_model->archive()->mimeType().inherits(QStringLiteral("application/x-cd-image")) &&
+               m_model->entryForIndex(m_model->index(0, 0))->fullPath() == QLatin1String("README.TXT")) {
+        qCWarning(ARK) << "Detected ISO image with UDF filesystem";
+        displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "Ark does not currently support ISO files with UDF filesystem."));
+    } else {
+        m_model->countEntriesAndSize();
     }
 
     if (arguments().metaData()[QStringLiteral("showExtractDialog")] == QLatin1String("true")) {
@@ -1043,11 +1057,11 @@ void Part::slotOpenExtractedEntry(KJob *job)
             // trigger the openWith dialog
             KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob();
             job->setUrls({url});
-            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
             job->start();
         } else {
             KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
-            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
             job->start();
         }
     } else if (job->error() != KJob::KilledJobError) {
@@ -1063,7 +1077,13 @@ void Part::slotPreviewExtractedEntry(KJob *job)
         Q_ASSERT(previewJob);
 
         m_tmpExtractDirList << previewJob->tempDir();
-        ArkViewer::view(previewJob->validatedFilePath());
+        // Use displayName to detect the mimetype, otherwise with single-file archives with fake 'data' entry the detected mime would be the default one.
+        QMimeType mimeType = QMimeDatabase().mimeTypeForFile(previewJob->entry()->displayName());
+        if (previewJob->entry()->displayName() != previewJob->entry()->name()) {
+            ArkViewer::view(previewJob->validatedFilePath(), previewJob->entry()->displayName(), mimeType);
+        } else {
+            ArkViewer::view(previewJob->validatedFilePath(), previewJob->entry()->fullPath(PathFormat::NoTrailingSlash), mimeType);
+        }
 
     } else if (job->error() != KJob::KilledJobError) {
         KMessageBox::error(widget(), job->errorString());
@@ -1112,10 +1132,20 @@ void Part::slotWatchedFileModified(const QString& file)
         prettyFilename = relPath + QLatin1Char('/') + file.section(QLatin1Char('/'), -1);
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::questionTwoActions(widget(),
+#else
     if (KMessageBox::questionYesNo(widget(),
-                               xi18n("The file <filename>%1</filename> was modified. Do you want to update the archive?",
-                                     prettyFilename),
-                               i18nc("@title:window", "File Modified")) == KMessageBox::Yes) {
+#endif
+                                        xi18n("The file <filename>%1</filename> was modified. Do you want to update the archive?", prettyFilename),
+                                        i18nc("@title:window", "File Modified"),
+                                        KGuiItem(i18nc("@action:button", "Update"), QStringLiteral("view-refresh")),
+                                        KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        == KMessageBox::PrimaryAction) {
+#else
+        == KMessageBox::Yes) {
+#endif
         QStringList list = QStringList() << file;
 
         qCDebug(ARK) << "Updating file" << file << "with path" << relPath;
@@ -1291,7 +1321,7 @@ void Part::slotExtractionDone(KJob* job)
             qCDebug(ARK) << "Shall open URL" << destinationDirectory;
 
             KIO::OpenUrlJob *job = new KIO::OpenUrlJob(destinationDirectory, QStringLiteral("inode/directory"));
-            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
             job->start();
         }
 
@@ -1599,6 +1629,8 @@ void Part::slotAddFilesDone(KJob* job)
             setArguments(args);
 
             openUrl(QUrl::fromLocalFile(m_model->archive()->multiVolumeName()));
+        } else {
+            m_model->countEntriesAndSize();
         }
     }
     m_cutIndexes.clear();
@@ -1610,6 +1642,8 @@ void Part::slotPasteFilesDone(KJob *job)
 {
     if (job->error() && job->error() != KJob::KilledJobError) {
         KMessageBox::error(widget(), job->errorString());
+    } else {
+        m_model->countEntriesAndSize();
     }
     m_cutIndexes.clear();
     m_model->filesToMove.clear();
@@ -1620,6 +1654,8 @@ void Part::slotDeleteFilesDone(KJob* job)
 {
     if (job->error() && job->error() != KJob::KilledJobError) {
         KMessageBox::error(widget(), job->errorString());
+    } else {
+        m_model->countEntriesAndSize();
     }
     m_cutIndexes.clear();
     m_model->filesToMove.clear();
@@ -1629,19 +1665,26 @@ void Part::slotDeleteFilesDone(KJob* job)
 void Part::slotDeleteFiles()
 {
     const int selectionsCount = m_view->selectionModel()->selectedRows().count();
-    const auto reallyDelete =
-        KMessageBox::questionYesNo(widget(),
-                                   i18ncp("@info",
-                                          "Deleting this file is not undoable. Are you sure you want to do this?",
-                                          "Deleting these files is not undoable. Are you sure you want to do this?",
-                                          selectionsCount),
-                                   i18ncp("@title:window", "Delete File", "Delete Files", selectionsCount),
-                                   KStandardGuiItem::del(),
-                                   KStandardGuiItem::no(),
-                                   QString(),
-                                   KMessageBox::Dangerous | KMessageBox::Notify);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const auto reallyDelete = KMessageBox::questionTwoActions(widget(),
+#else
+    const auto reallyDelete = KMessageBox::questionYesNo(widget(),
+#endif
+                                                              i18ncp("@info",
+                                                                     "Deleting this file is not undoable. Are you sure you want to do this?",
+                                                                     "Deleting these files is not undoable. Are you sure you want to do this?",
+                                                                     selectionsCount),
+                                                              i18ncp("@title:window", "Delete File", "Delete Files", selectionsCount),
+                                                              KStandardGuiItem::del(),
+                                                              KStandardGuiItem::cancel(),
+                                                              QString(),
+                                                              KMessageBox::Dangerous | KMessageBox::Notify);
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (reallyDelete == KMessageBox::SecondaryAction) {
+#else
     if (reallyDelete == KMessageBox::No) {
+#endif
         return;
     }
 
@@ -1654,7 +1697,6 @@ void Part::slotDeleteFiles()
 
 void Part::slotShowProperties()
 {
-    m_model->countEntriesAndSize();
     QPointer<Kerfuffle::PropertiesDialog> dialog(new Kerfuffle::PropertiesDialog(nullptr,
                                                                                  m_model->archive(),
                                                                                  m_model->numberOfFiles(),
@@ -1714,6 +1756,9 @@ void Part::slotShowContextMenu()
     }
 
     QMenu *popup = static_cast<QMenu *>(factory()->container(QStringLiteral("context_menu"), this));
+    if (KHamburgerMenu * const hamburgerMenu = static_cast<KHamburgerMenu *>(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::HamburgerMenu))))) {
+        hamburgerMenu->insertIntoMenuBefore(popup, popup->actions().constFirst());
+    }
     popup->popup(QCursor::pos());
 }
 
